import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'custom-widget-provider/custom-services.dart';
import 'widget-classesUsed.dart';

class CustomTextField extends StatefulWidget {
  final TextFieldParameters tFparams;
  CustomTextField({this.tFparams});

  @override
  _CustomTextFieldState createState() => _CustomTextFieldState();
}

class _CustomTextFieldState extends State<CustomTextField> {
  FocusNode _focusNode;

  @override
  void initState() {
    super.initState();
    _focusNode = FocusNode();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_focusNode);
    });
  }

  @override
  void dispose() {
    _focusNode.dispose();
    widget.tFparams.controller.dispose();
    super.dispose();
  }
  @override
  Widget build(BuildContext context) {
    String change = '';
    return TextField(
      controller: widget.tFparams.controller,
      focusNode: _focusNode,
      onTap: _requestFocus,
      maxLength:
      (widget.tFparams.maxLength != null) ? widget.tFparams.maxLength : 50,
      maxLengthEnforced: (widget.tFparams.maxLengthEnforced != null)
          ? widget.tFparams.maxLengthEnforced
          : false,
      obscureText: (widget.tFparams.obscureText != null)
          ? widget.tFparams.obscureText
          : false,
      //controller: controller,
      decoration: (widget.tFparams.prefixIcon != null)
          ? InputDecoration(
        counterText: "",
        errorText: widget.tFparams.errorText,
        hintText: (widget.tFparams.hintText != 'null')
            ? widget.tFparams.hintText
            : '',
        labelText: (widget.tFparams.hintText != 'null')
            ? widget.tFparams.labelText
            : '',
        labelStyle : TextStyle(
          color: _focusNode.hasFocus ? (widget.tFparams.focusedBorderColor?? Colors.blue) : Colors.blue,
        ),
        prefixIcon: Icon(
          widget.tFparams.prefixIcon,
          color: widget.tFparams.iconColor ?? Colors.transparent,
        ),
        suffixIcon: Icon(
          widget.tFparams.suffixIcon,
          color: widget.tFparams.iconColor ?? Colors.transparent,
        ),
        fillColor: (widget.tFparams.fillColor != null)
            ? widget.tFparams.fillColor
            : Colors.transparent,
        filled: (widget.tFparams.filled != null)
            ? widget.tFparams.filled
            : false,
        border: OutlineInputBorder(
          borderRadius: BorderRadius.circular(
              (widget.tFparams.borderRadius != null)
                  ? widget.tFparams.borderRadius
                  : 0),
          borderSide: BorderSide(
              color: widget.tFparams.borderColor,
              style: BorderStyle.solid,
              width: 5),
        ),
        focusedBorder: OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(10)),
          borderSide: BorderSide(width: widget.tFparams.focusedBorderWidth??1,color: widget.tFparams.focusedBorderColor??Colors.blue),
        ),
        disabledBorder: OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(4)),
          borderSide: BorderSide(width: 1,color: Colors.orange),
        ),
        enabledBorder: OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(10)),
          borderSide: BorderSide(width: widget.tFparams.enabledBorderWidth??1,color: widget.tFparams.enabledBorderColor??Colors.blue),
        ),

        errorBorder: OutlineInputBorder(
            borderRadius: BorderRadius.all(Radius.circular(4)),
            borderSide: BorderSide(width: 1,color: Colors.black)
        ),
        focusedErrorBorder: OutlineInputBorder(
            borderRadius: BorderRadius.all(Radius.circular(4)),
            borderSide: BorderSide(width: 1,color: Colors.yellowAccent)
        ),
      )
          : InputDecoration(
        counterText: "",
        errorText: widget.tFparams.errorText,
        hintText: (widget.tFparams.hintText != 'null')
            ? widget.tFparams.hintText
            : '',
        labelText: (widget.tFparams.hintText != 'null')
            ? widget.tFparams.labelText
            : '',
        labelStyle : TextStyle(
          color: _focusNode.hasFocus ? (widget.tFparams.focusedBorderColor?? Colors.blue) : Colors.blue,
        ),
        
        fillColor: (widget.tFparams.fillColor != null)
            ? widget.tFparams.fillColor
            : Colors.transparent,
        filled: (widget.tFparams.filled != null)
            ? widget.tFparams.filled
            : false,
        border: OutlineInputBorder(
          borderRadius: BorderRadius.circular(
              (widget.tFparams.borderRadius != null)
                  ? widget.tFparams.borderRadius
                  : 0),
          borderSide: BorderSide(
              color: widget.tFparams.borderColor,
              style: BorderStyle.solid,
              width: 5),

        ),
        focusedBorder: OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(10)),
          borderSide: BorderSide(width: widget.tFparams.focusedBorderWidth??1,color: widget.tFparams.focusedBorderColor??Colors.blue),
        ),
        disabledBorder: OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(4)),
          borderSide: BorderSide(width: 1,color: Colors.orange),
        ),
        enabledBorder: OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(10)),
          borderSide: BorderSide(width: widget.tFparams.enabledBorderWidth??1,color: widget.tFparams.enabledBorderColor??Colors.blue),
        ),

        errorBorder: OutlineInputBorder(
            borderRadius: BorderRadius.all(Radius.circular(4)),
            borderSide: BorderSide(width: 1,color: Colors.black)
        ),
        focusedErrorBorder: OutlineInputBorder(
            borderRadius: BorderRadius.all(Radius.circular(4)),
            borderSide: BorderSide(width: 1,color: Colors.yellowAccent)
        ),
      ),


      cursorColor: widget.tFparams.cursorColor ?? Colors.blueAccent,
      cursorHeight: widget.tFparams.cursorHeight ?? 20,
      cursorWidth: widget.tFparams.cursorWidth ?? 2,
      showCursor: (widget.tFparams.showCursor != null)
          ? widget.tFparams.showCursor
          : true,
      style: GoogleFonts.getFont((widget.tFparams.fontFamily != null)
          ? checkFonts(widget.tFparams.fontFamily)
          : 'Roboto',
        color: widget.tFparams.textColor ?? Colors.black54,
        fontSize:(widget.tFparams.textFontSize != null) ? widget.tFparams.textFontSize : 12.0,
        fontWeight: (widget.tFparams.fontWeight != null)
            ? widget.tFparams.fontWeight
            : FontWeight.normal,
        fontStyle: (widget.tFparams.fontStyle != null)
            ? widget.tFparams.fontStyle
            : FontStyle.normal,
      ),
      onChanged: (String temp) {
        setState(() {
          change = temp;
        });
        //print(e);
      },
    );
  }
}
